@@ -44,6 +44,7 @@ class SeleniumDriverCore(object):
         self.debug = initialization_options.get('debug', False)
         self.train = initialization_options.get('train', False)
         self.use_cdp = initialization_options.get('use_cdp', False)
+        self.use_ai_elem = initialization_options.get('use_ai_elem', False)
         self.url = initialization_options.get('server_url',
                 os.environ.get('DEVTOOLSAI_URL', 'https://smartdriver.dev-tools.ai'))
         self.default_prod_url = 'https://smartdriver.dev-tools.ai'
@@ -58,7 +59,6 @@ class SeleniumDriverCore(object):
         if self.test_case_creation_mode:
             self.use_classifier_during_creation = initialization_options.get('use_classifier_during_creation', True)
 
-
         self._checkin()
         window_size = self.driver.get_window_size()
         screenshotBase64 = self._get_screenshot()
@@ -270,7 +270,6 @@ class SeleniumDriverCore(object):
         if element_name is None:
             element_name = 'element_name_by_name_%s' % (str(name).replace('.', '_'))
         element_name = element_name.replace(' ', '_')
-        print(element_name)
         return self._generic_find_method(
             self.driver.find_element_by_name, element_name, name)
 
@@ -576,7 +575,7 @@ class SeleniumDriverCore(object):
         composite = sorted(zip(iou_scores, elements), reverse=True, key=lambda x: x[0])
         # Pick the best match
         """
-        We have to be smart about element selection here because of clicks being intercepted and what not, so we basically 
+        We have to be smart about element selection here because of clicks being intercepted and what not, so we basically
         examine the elements in order of decreasing score, where score > 0. As long as the center of the box is within the elements,
         they are a valid candidate. If none of them is of type input, we pick the one with maxIOU, otherwise we pick the input type,
         which is 90% of test cases.
